@@ -2,7 +2,9 @@
 #define INCLUDED_AGEGROUPVSD_
 
 #include <iosfwd>
-#include "../agegroup/agegroup.h"
+#include <vector>
+
+#include "../group/group.h"
 #include "../vsd/vsd.h"
 
 class AgeGroupVSD
@@ -12,7 +14,9 @@ class AgeGroupVSD
                                     std::vector<AgeGroupVSD> const &vect);
     friend std::ostream &operator<<(std::ostream &out, 
                                                 AgeGroupVSD const &group);
-    AgeGroup d_ageGroup;
+
+    bool d_extractGroup;
+    Group d_group;
 
     VSD      d_vsd;
     double   d_stdDev;      // if negative: std dev not used
@@ -20,17 +24,18 @@ class AgeGroupVSD
     static unsigned s_indent;
 
     public:
-        AgeGroupVSD(VaryType varyType, bool useStdDev);
+        AgeGroupVSD(VaryType varyType, bool useStdDev, 
+                                       bool etractGroup = true);
 
-        AgeGroup const &ageGroup() const;
+        Group const &group() const;                                     // .f
 
-        uint16_t beginAge() const;
-        uint16_t endAge() const;
+        uint16_t beginAge() const;                                      // .f
+        uint16_t endAge() const;                                        // .f
 
-        double value() const;
-        double stdDev() const;
+        double value() const;                                           // .f
+        double stdDev() const;                                          // .f
 
-        void vary();
+        void vary();                                                    // 1
 
         static void fmt(unsigned valueIntWidth, unsigned valuePrec,     // inl
                         unsigned distValueWdith, unsigned distPrec);
@@ -39,6 +44,7 @@ class AgeGroupVSD
                         unsigned mIntWidth, unsigned mPrec, 
                         unsigned sdIntWidth, unsigned sdPrec);
 
+                                                    // hdr should end in ':'
         static void vary(std::ostream &out, unsigned indent,            // 2
                         char const *hdr, std::vector<AgeGroupVSD> &vect);
 
@@ -51,56 +57,9 @@ class AgeGroupVSD
         std::istream &extract(std::istream &in);
 };
 
-typedef std::vector<AgeGroupVSD> AgeGroupVSDvect;
+using AgeGroupVSDvect = std::vector<AgeGroupVSD>;
 
-inline AgeGroup const &AgeGroupVSD::ageGroup() const
-{
-    return d_ageGroup;
-}
-
-inline uint16_t AgeGroupVSD::beginAge() const
-{
-    return d_ageGroup.beginAge();
-}
-
-inline uint16_t AgeGroupVSD::endAge() const
-{
-    return d_ageGroup.endAge();
-}
-
-inline double AgeGroupVSD::value() const
-{
-    return d_vsd.value();
-}
-
-inline double AgeGroupVSD::stdDev() const
-{
-    return d_stdDev;
-}
-
-// static
-inline void fmt(unsigned valueIntWidth, unsigned valuePrec,    
-                unsigned distValueWdith, unsigned distPrec)
-{
-    VSD::fmt(valueIntWidth, valuePrec, distValueWdith, distPrec);
-}
-
-inline std::istream &operator>>(std::istream &in, AgeGroupVSD &ageGroupVSD)
-{
-    return ageGroupVSD.extract(in);
-}
-
-inline std::ostream &operator<<(std::ostream &out, 
-                                            AgeGroupVSD const &ageGroupVSD)
-{
-    return ageGroupVSD.insert(out);
-}
-
-inline std::ostream &operator<<(std::ostream &out, 
-                                AgeGroupVSDvect const &vect)
-{
-    return AgeGroupVSD::insert(out, vect);
-}
+#include "agegroupvsd.f"
 
 #endif
 
