@@ -1,7 +1,7 @@
-//#define XERR
+#define XERR
 #include "analysis.ih"
 
-void Analysis::actualize(Parser::OptionsVect const &specs)
+void Analysis::actualize(Parser::OptionsVect const &optionsVect)
 {
     auto &options = Options::instance();
 
@@ -9,7 +9,7 @@ void Analysis::actualize(Parser::OptionsVect const &specs)
                                                 // (default/command-line)
                                                 // options
 
-    for (auto const &spec: specs)               // visit all options specified
+    for (auto const &spec: optionsVect)         // visit all options specified
     {                                           // in this analysis
 
                                                 // visit all long options
