@@ -4,7 +4,8 @@
 void Beir7::vary(ostream &out)
 {
     d_vsd.vary();
-    out << "  beir7:  ";
+    out << "  Beir7:\n"
+           "    " << Globals::simTypeLabel(LC) << "  ";
     d_vsd.showVary(out);
 }
 
