@@ -4,7 +4,7 @@
 uint16_t Costs::cost(double diameter) const
 {
                     // reversed search: start at the max. diameter
-    return find_if(d_treatment.rbegin(), d_treatment.rend(),
+    return find_if(d_treatmntPair.rbegin(), d_treatmntPair.rend(),
                 [&](CostPair const &costPair)
                 {
                     return diameter >= costPair.first;
