@@ -19,12 +19,12 @@ bool Costs::extractDiameters(Parser::Lines &&lines)
         if (not (in.ignore() >> spec.second))   // followed by treatment
             return false;                       // cost. Ends at an
                                                 // incomplete entry
-        d_treatment.push_back(spec);
+        d_treatmntPair.push_back(spec);
         lastAge = spec.first;
     }
 
-    return  d_treatment.size() > 0 
+    return  d_treatmntPair.size() > 0 
             and 
-            Globals::isPositiveZero(d_treatment.front().first);
+            Globals::isPositiveZero(d_treatmntPair.front().first);
 }
 
