@@ -3,6 +3,8 @@
 
 void Costs::setAge()
 {
-    d_base.back() = "age:";
+    // d_base = { "Costs:", "Discount:"}
+
+    d_base.push_back("age:");
     Parser::nonNegative(d_base, d_referenceAge);    
 }
