@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "densities.ih"
 
 //  #                bi-rad:  a      b      c      d
@@ -6,7 +6,7 @@
 
 void Densities::add(bool *checkRange, LineInfo const &line)
 {
-    Density density;
+    ProbGroup density;
 
     if (not Parser::extract(line, density))         // density spec. error
     {
@@ -14,9 +14,11 @@ void Densities::add(bool *checkRange, LineInfo const &line)
         return;
     }
 
+//xerr("ProbGroup: " << density);
+
     Err::Context context;
 
-    if (not proportions(density.birad()))
+    if (not percentages(density.prob()))
         context = Err::RANGE_0_1;
 
     else if (not density.sumOne())
@@ -26,7 +28,7 @@ void Densities::add(bool *checkRange, LineInfo const &line)
     {
         if (*checkRange)
         {
-            if (density.ageGroup().nextRange(d_densities))
+            if (density.group().nextRange(d_densities))
                 d_densities.push_back(density);
             else
                 *checkRange = false;
