@@ -14,35 +14,49 @@
 
 #include <iosfwd>
 
-#include "../density/density.h"
+#include "../probgroup/probgroup.h"
 #include "../typedefs/typedefs.h"
 
 class Densities
 {
     StringVect  d_base;
-    DensityVect d_densities;
+    ProbGroup::Vector d_densities;  // contains the ageGroup data
 
     public:
         Densities();
-                                        // randomly determined bi-rad indices
-                                        // for screening round ages
-        Uint16Vect biRadIndices(DoubleVect const &ages) const;
+
+        ProbGroup::Vector const *biRad() const;
+
 
         void writeParameters(std::ostream &out) const;
 
     private:
         void add(bool *checkRange, LineInfo const &ageGroup);
 
-        bool nextRange(Density const &next) const;
+        bool nextRange(ProbGroup const &next) const;
+
+        static bool percentages(std::vector<double> const &vect);
+};
+        
+inline ProbGroup::Vector const *Densities::biRad() const
+{
+    return &d_densities;
+}
 
                                                 // birad idx for age, given 
                                                 // its probability
-        uint16_t biradIdx(double age, double prob) const;
+//        uint16_t biradIdx(double age, double prob) const;
+
+                                        // randomly determined bi-rad indices
+                                        // for screening round ages
+//        Uint16Vect biRadIndices(DoubleVect const &ages) const;
 
-        static bool proportions(std::vector<double> const &vect);
-};
-        
 #endif
 
 
 
+
+
+
+
+
