@@ -5,6 +5,9 @@ Densities::Densities()
 :
     d_base{ "BreastDensities:", "ageGroup:" }
 {
+    if (Globals::simulationType() != BREAST)
+        return;
+
                                 // retrieve the Densities: ageGroup: lines
     auto lines = Parser::any(d_base);
 
