@@ -8,7 +8,7 @@ void Densities::writeParameters(std::ostream &out) const
 
     Globals::setWidthPrec(out, 3, 2);
 
-    for (Density const &density: d_densities)
+    for (ProbGroup const &density: d_densities)
         out << setw(2) << ' ' << density << '\n';
 
     out.put('\n');
