@@ -9,16 +9,16 @@ double Distribution::varyMean(double orgValue) const
 {
     Random &random = Random::instance();
 
-    switch (d_type)
+    switch (d_distType)
     {
         case NORMAL_VARY:
-        return orgValue + random.normalVary() * d_value;
+        return orgValue + random.normalVary() * d_confValue;
 
         case UNIFORM_VARY:
-        return orgValue + d_value * (random.uniformVary() - .5);
+        return orgValue + d_confValue * (random.uniformVary() - .5);
 
         case LOGNORMAL_VARY:
-        return random.logNormalVary(orgValue, d_value);
+        return random.logNormalVary(orgValue, d_confValue);
 
         default:
         return orgValue;
