@@ -12,6 +12,6 @@ double Distribution::varyNonNeg(double orgValue) const
 
     throw Exception{} << 
         "failed to obtain non-negative spread value for " <<
-        orgValue << " (spread = " << d_value << 
-                    ", distribution: " << name(d_type) << ')';
+        orgValue << " (spread = " << d_confValue << 
+                    ", distribution: " << name(d_distType) << ')';
 }
