@@ -14,6 +14,6 @@ double Distribution::varyProb(double orgValue) const
 
     throw Exception{} << 
         "failed to obtain spread proportion for " <<
-        orgValue << " (spread = " << d_value << 
-                    ", distribution: " << name(d_type) << ')';
+        orgValue << " (spread parameter = " << d_confValue << 
+                    ", distribution: " << name(d_distType) << ')';
 }
