@@ -19,26 +19,35 @@ char const *Err::s_plain[]              // plain msg: no line context
     "Incidence carrier probabilites must sum to 1"  , // INCIDENCE_SUM_PROB
     "specification(s) missing for"                  , // MISSING_SPEC
     "multiply specified: "                          , // MULTIPLY_SPECIFIED
+    "CT: unknown sensitivity for diameter "         , // CT_NO_SENS,
     "undefined specification"                       , // UNDEFINED_SPEC
+    "Cumulative death proportions ("                , // CUM_DEATH
 };
 
 char const *Err::s_context[]            // line context available
 {
-    "parameter value too small"             , // AT_LEAST       
-    "invalid Survival type"                 , // INVALID_TYPE
-    "invalid value"                         , // INVALID_VALUE
-    "modality repeatedly specified"         , // MODALITY_REPEATED
-    "parameter cannot be negative"          , // NEGATIVE
-    "age ranges not consecutive"            , // NOT_CONSECUTIVE
-    "proportions must sum to 1"             , // PROB_SUM,
-    "parameter(s) must lie within 0..1"     , // RANGE_0_1
-    "screening round ages don't increment"  , // ROUND_AGES_DONT_INC
-    "`round: none' conflicts with "  
-              "`round: age' specifications" , // ROUND_NONE
-    "specification error"                   , // SPEC_ERROR
-    "undefined distribution"                , // UNDEFINED_DIST
-    "undefined modality"                    , // UNDEFINED_MODALITY
-    "VSD specification missing. Require "   , // VSD_MISSING
+    "parameter value too small"                 ,   // AT_LEAST
+    "CT sensitivity must be 0..100 or -1"       ,   // CT_SENS
+    "CT sensitivity diameters must cover 0..*"  ,   // CT_SENS_RANGE
+    "Group specifications must end in :"        ,   // GROUP_NO_COLON
+    "invalid Survival type"                     ,   // INVALID_TYPE
+    "invalid value"                             ,   // INVALID_VALUE
+    "modality repeatedly specified"             ,   // MODALITY_REPEATED
+    "parameter cannot be negative"              ,   // NEGATIVE
+    "age ranges not consecutive"                ,   // NOT_CONSECUTIVE
+    "percentages must sum to 1"                 ,   // PROB_SUM,
+    "parameter(s) must lie within 0..1"         ,   // RANGE_0_1
+    "screening round ages don't increment"      ,   // ROUND_AGES_DONT_INC
+    "`round: none' conflicts with "                 
+              "`round: age' specifications"     ,   // ROUND_NONE
+    "specification error"                       ,   // SPEC_ERROR
+    "undefined distribution"                    ,   // UNDEFINED_DIST
+    "undefined modality"                        ,   // UNDEFINED_MODALITY
+    "VSD specification missing. Require "       ,   // VSD_MISSING
+    "Lung cancer simulations cannot specify "       // LC_INVALID_MODALITY
+                                "modality "     ,
+    "Breast cancer simulations cannot specify "     // BC_CT_INVALID
+                                "modality CT"   ,
 };
 
 
