@@ -25,12 +25,17 @@ class Err
             INCIDENCE_SUM_PROB,
             MISSING_SPEC,
             MULTIPLY_SPECIFIED,
+            CT_NO_SENS,
             UNDEFINED_SPEC,
+            CUM_DEATH,
         };
         
         enum Context
         {
             AT_LEAST,
+            CT_SENS,
+            CT_SENS_RANGE,
+            GROUP_NO_COLON,
             INVALID_TYPE,
             INVALID_VALUE,
             MODALITY_REPEATED,
@@ -44,6 +49,8 @@ class Err
             UNDEFINED_DIST,
             UNDEFINED_MODALITY,
             VSD_MISSING,
+            LC_INVALID_MODALITY,
+            BC_CT_INVALID,
         };
         
         static char const *src(ParamsSrc type);
