@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "err.ih"
 
 ostream &Err::msg(Plain plain)              // no line context
