@@ -1,6 +1,8 @@
-//#define XERR
+#define XERR
 #include "err.ih"
 
+//#include <iostream>
+
                                 // line context available
 ostream &Err::msg(Context err)
 {
