@@ -3,7 +3,8 @@
 
 Growth::Growth()
 :
-    d_base{ "Tumor:", "Growth:", "" }
+    d_base{ "Tumor:", "Growth:", "" },
+    d_selfMean(VARY_NONNEG)
 {
     setStart();
     setSelfDetect();
