@@ -11,5 +11,6 @@ void Growth::vary(ostream &out)
     d_selfMean.showVary(out);
     out.put('\n');
 
-    AgeGroupVSD::vary(out, 4, "DoublingTime", d_doublingTime);
+    AgeGroupVSD::vary(out, 2,   // d_doublingTime.size(), 
+                           "DoublingTime:", d_doublingTime);
 }
