@@ -16,5 +16,5 @@ void Growth::writeParameters(ostream &out) const
 
     AgeGroupVSD::fmt(8, 1, 2, 0, 2);
     out << setw(6) << ' ' << "DoublingTime:\n" <<
-           d_doublingTime;
+           d_doublingTime << '\n';
 }
