@@ -1,16 +1,35 @@
-//#define XERR
+#define XERR
 #include "incidence.ih"
 
 void Incidence::writeParameters(ostream &out) const
 {
     out << "    Incidence:\n";
 
-    for (size_t idx = 0; idx != s_carrier.size(); ++idx)
+    auto simulationType = Globals::simulationType();
+
+    for (
+        size_t idx = 0, end = simulationType == BREAST ? 3 : 1; 
+            idx != end;
+                ++idx
+    )
     {
+        string label;
+        switch (simulationType)
+        {
+            case BREAST:
+                label = s_incidence[idx];
+            break;
+
+            case FEMALE:
+            case MALE:
+                label = Globals::label(simulationType);
+            break;
+        }
+
         auto &param = d_params[idx];
 
         Globals::setPrecision(out, 1) <<  
-            setw(6) << ' ' << s_carrier[idx] << '\n' <<
+            setw(6) << ' ' << label << '\n' <<
                setw(8) << ' ' << "probability:   " << 
                     param.prob() << 
                     (
@@ -27,7 +46,7 @@ void Incidence::writeParameters(ostream &out) const
         out << setw(8) << ' ' << "lifetimeRisk: " << param.risk() << '\n';
 
         VSD::fmt(2, 1, 3, 3);
-        out << setw(8) << ' ' << "mean age:     " << param.mean() << '\n';
+        out << setw(8) << ' ' << "mean age:     " << param.mean() << "\n\n";
     }
 }
 
