@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "loop.ih"
 
         // if last case (--nCases) was specified, use that number of cases
@@ -7,10 +7,8 @@
 
 size_t Loop::cases() const
 {
-    auto const &options = Options::instance();
-
     return 
-        options.lastCase() != 0 ? options.lastCase()    :
-        options.specificAges()  ? 1                     :
+        d_options.lastCase() != 0 ? d_options.lastCase()    :
+        d_options.specificAges()  ? 1                     :
                                   d_scenario.nCases();
 }
