@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "loop.ih"
 
 void Loop::characteristics(Status natural, Status tumor)
@@ -11,7 +11,8 @@ void Loop::characteristics(Status natural, Status tumor)
         // treat the tumor: add the treatment cost and compute the age of
         // tumor-caused death. There is a tumor: no need to call
         // diameterCheck()
-    d_caseCost += d_costs.treatment(d_tumor.age(), d_tumor.diameter());
+    d_caseCost += treatmentCosts(d_tumor.selfDetectAge());
+
     d_tumor.setDeathAge();
 
     if (d_naturalDeathAge < d_tumor.deathAge())     // naturally caused death
@@ -20,8 +21,8 @@ void Loop::characteristics(Status natural, Status tumor)
         setStatus(tumor, d_tumor.deathAge());
 }
 
-// double cost = d_costs.treatment(d_tumor.age(), d_tumor.diameter()); 
-// xerr("costs: " << cost << ", age: " << d_tumor.age() << ", dia: " <<[bsl]
+// double cost = treatmentCosts(d_tumor.selfDetectAge());
+// xerr("costs: " << cost << ", age: " << d_tumor.selfDetectAge() << ", dia: " <<[bsl]
 // d_tumor.diameter());
 // d_caseCost += cost;
 
