@@ -7,27 +7,32 @@ void Loop::genCases(size_t iter, size_t nCases)
 {
     CSVTable dataTable = headerData(iter);
 
-    auto const &options = Options::instance();
-
-    bool showAll = not options.specificAges() and options.lastCase() == 0;
+    bool showAll = not d_options.specificAges() and d_options.lastCase() == 0;
 
                                         // perform 'nCases' simulations
     for (size_t caseIdx = 0; caseIdx != nCases; ++caseIdx)
     {
+        //xerr("caseInit " << caseIdx << ' ' << nCases);
         caseInit();
+
+        //xerr("preScreen");
         preScreen();        // no action unless screening rounds are specified
+
+        //xerr("screening");
         screening();        // same
+
+        //xerr("postScreen");
         postScreen();
 
         d_sumDeathAge += d_deathAge;
         d_totalCost += d_caseCost;
 
+        //xerr("write data");
         if (dataTable.stream() and (showAll or caseIdx + 1 == nCases))
             writeData(dataTable, caseIdx);
     }
 
     dataTable << hline();
-
 }
 
 // In the original womanloop function a test is performed whether the
