@@ -9,7 +9,7 @@
 
 CSVTable Loop::headerData(size_t iter) const
 {
-    CSVTable tab{ outStream(Options::instance().dataFile(), iter), "  " };
+    CSVTable tab{ outStream(d_options.dataFile(), iter), "  " };
 
     if (not tab.stream())
         return tab;
