@@ -4,7 +4,7 @@
 CSVTable Loop::headerRounds(size_t iteration) const
 {
    CSVTable tab{ outStream(
-        d_nRounds == 0 ? "" : Options::instance().roundsFile(), iteration),
+        d_nRounds == 0 ? "" : d_options.roundsFile(), iteration),
                  "  " };
 
 //          false        number of                   number of
