@@ -1,4 +1,4 @@
-#define XERR
+//#define XERR
 #include "loop.ih"
 
 // -----------------------------------
@@ -10,15 +10,21 @@
 
 CSVTable Loop::headerSensitivity() const
 {
-    CSVTable tab{ outStream(Options::instance().sensitivityFile(), 0), "  " };
+xerr("0");
 
+    CSVTable tab{ outStream(d_options.sensitivityFile(), 0), "  " };
+
+xerr("1");
     if (not tab.stream())
         return tab;
 
+xerr("2");
     labels(tab.stream());
 
+xerr("3");
     tab.fmt("iteration, women years, total costs");
 
+xerr("4");
     tab << hline();
     tab("iteration, women years, total costs");
     tab << hline();
