@@ -14,7 +14,7 @@ void Loop::intervalCancer()
     
         // treat the tumor and determine the death-age of the women
         // since the tumor is present, no need to call diameterCheck()
-    addCost(d_costs.treatment(d_tumor.age(), d_tumor.diameter()));
+    addCost(treatmentCosts(d_tumor.selfDetectAge()));
 
     d_tumor.setDeathAge();
     
