@@ -16,12 +16,11 @@ void Loop::iterate()
 
         size_t nCases = cases();
 
-        Random::instance().reinit(nCases, d_scenario.vary(), 
-                                          d_scenario.generatorType());  
+        Random::instance().reinit(nCases, d_scenario.generatorType());
 
-        if (d_scenario.vary())      // maybe vary the parameters
+        if (Globals::vary())                    // maybe vary the parameters
         {
-            spreadStream = outStream(Options::instance().spreadFile(), idx);
+            spreadStream = outStream(d_options.spreadFile(), idx);
             labels(spreadStream);
             
             d_modalities.vary(spreadStream);    // vary the used modalities
