@@ -3,7 +3,8 @@
 
 void Loop::labels(ostream &out) const
 {
-    out << "Analysis " << d_timestamp << '\n';
+    out << "Analysis " << d_timestamp << 
+                        " (SimRisc V. " << Icmake::version << ")\n";
 
     for (auto const &line: d_labels)
         out << line << '\n';
