@@ -5,10 +5,10 @@
 
 double Loop::naturalDeathAge()
 {
-//    double rnd;
-    double ret = findAge(s_cumDeathProb, 
-//                         rnd = 
-                            Random::instance().uniformCase());
+//double rnd;
+    double ret = findAge(d_scenario.cumDeathProp(),
+//rnd =
+        Random::instance().uniformCase());
 
 xerr(idx++ << ": nat.death: " << ret << ", rnd: " << rnd);
 
