@@ -8,6 +8,6 @@ void Loop::preTumorDeath()
 {
     setStatus(LEFT_PRE, d_naturalDeathAge);
 
-    if (d_tumor)        // would have developed a tumor. Compute the tumor's
-        d_tumor.characteristics(d_deathAge);    // characteristics
+    if (d_tumor.selfDetectable())    // would have developed a tumor. Compute the 
+        d_tumor.characteristics(d_deathAge);    // tumor's characteristics
 }
