@@ -5,7 +5,7 @@ void Loop::screening()
 {
     for (d_round = 0; d_status == PRESENT and d_round != d_nRounds; ++d_round)
     {
-        double screeningAge = d_screening.age(d_round);
+        double screeningAge = d_screening.roundAge(d_round);
 
         if (leaving(screeningAge))
             return;
