@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "main.ih"
 
                             // update Options::alter, Options::inspect and
@@ -6,7 +6,10 @@
 Arg::LongOption g_longOpts[] =
 {
     Arg::LongOption{"base",         'B'},
+    Arg::LongOption{"cancer",       'c' },    // breast (def.),
+                                              // male, or female (implies LC)
     Arg::LongOption{"config",       'C'},
+    Arg::LongOption{"cum-death",    'd'},
     Arg::LongOption{"data",         'D'},
     Arg::LongOption{"death-age",    'a'},
     Arg::LongOption{"err",          'e'},
@@ -28,7 +31,7 @@ auto const *g_longEnd = g_longOpts + size(g_longOpts);
 int main(int argc, char **argv)
 try
 {
-    Arg const &arg = Arg::initialize("a:B:el:C:D:hoP:R:S:s:t:vV",
+    Arg const &arg = Arg::initialize("a:B:c:C:d:D:el:hoP:R:S:s:t:vV",
                                       g_longOpts, g_longEnd, argc, argv);
     arg.versionHelp(usage, Icmake::version, arg.option('o') ? 0 : 1);
 
@@ -47,7 +50,6 @@ catch (exception const &exc)
     cerr << exc.what() << '\n';
     return 1;
 }
-
 catch (...)
 {
     cerr << "unexpected exception\n";
