@@ -5,37 +5,20 @@
 #include "../modbase/modbase.h"
 #include "../agegroupvsd/agegroupvsd.h"
 
-//Mammo:
-//    costs:          64   
+//  Mammo:
+//      costs:          64   
 //
-//    systematicError:  0.1   
+//      #      bi-rad:  a       b       c       d             
+//      dose:           3       3       3       3  
+//      m:             .136    .136    .136    .136
 //
-//    Dose:           
-//      #            mean   spread    dist
-//      bi-rad: a     3       1       Normal
-//      bi-rad: b     3       1       Normal
-//      bi-rad: c     3       1       Normal
-//      bi-rad: d     3       1       Normal
+//      #             ageGroup
+//      specificity:  0 - 40:  .961     40 - *: .965
 //
-//     M: 
-//      #            proportion   spread      dist    
-//      bi-rad: a      .061        .021       Normal
-//      bi-rad: b      .163        .045       Normal
-//      bi-rad: c      .400        .106       Normal
-//      bi-rad: d      .826        .088       Normal
+//      #       1       2       3        4    
+//      beta:  -4.38    .49     -1.34    -7.18
 //
-//     Beta:
-//      #         mean    spread      dist
-//      nr: 1     -4.38    .002       Normal
-//      nr: 2       .49    .0005      Normal
-//      nr: 3     -1.34    .0074      Normal
-//      nr: 4     -7.18    .0340      Normal
-//
-//    Specificity:
-//      #           range      proporion   spread  dist
-//      ageGroup:   0 - 40     .961        .005    Normal
-//      ageGroup:  40 - *      .965        .005    Normal
-
+//      systematicError:  0.1   
 
 class Tumor;
 
@@ -45,8 +28,6 @@ class Mammo: public ModBase
 
     double d_sysErr;
 
-    StringVect d_base;
-
     VSDvect d_dose;
     VSDvect d_m;
     VSDvect d_beta;
