@@ -3,5 +3,5 @@
 
 double Mammo::vDose(uint16_t idx) const
 {
-    return d_dose[idx];
+    return d_dose[idx].value();
 }
