@@ -9,14 +9,14 @@
 double Mammo::vSensitivity(size_t idx) const
 {
     double diameter = d_tumor.diameter();
-    double mValue = d_m[idx];
+    double mValue = d_m[idx].value();
 
     double expBeta = 
         exp(
-            d_beta[0]            +
-            d_beta[1] * diameter +
-            d_beta[2] * mValue   +
-            d_beta[3] * mValue / (diameter * diameter)
+            d_beta[0].value()            +
+            d_beta[1].value() * diameter +
+            d_beta[2].value() * mValue   +
+            d_beta[3].value() * mValue / (diameter * diameter)
         );
   
     return  (1 - d_sysErr) * expBeta / (1 + expBeta);
