@@ -13,7 +13,7 @@
 double Mammo::vSpecificity(double age) const
 {
     return find_if(d_specVect.rbegin(), d_specVect.rend(), 
-                    [&](Specificity const &spec)
+                    [&](AgeGroupVSD const &spec)
                     {
                         return spec.beginAge() < age;
                     }
