@@ -3,6 +3,12 @@
 
 void Modalities::addMod(ModBase *modBase)
 {
+    if (not modBase->defined())
+    {
+        delete modBase;
+        return;
+    }
+
     d_modBaseVect.push_back(modBase);
     d_modalityIDs.push_back(modBase->id());
 }
