@@ -10,5 +10,8 @@ uint16_t Modalities::find(std::string const &modality) const
                         }
                 );
 
-    return iter != d_modalityIDs.end() ? iter - d_modalityIDs.begin() : ~0U;
+    return iter != d_modalityIDs.end() ? 
+                        iter - d_modalityIDs.begin() 
+                    : 
+                        UNDEFINED;
 }
