@@ -19,7 +19,7 @@ namespace FBB
 
 class Modalities
 {
-    Tumor const &d_tumor;               // used by Mammo
+    Tumor const &d_tumor;               // used by Mammo and CT
 
                                         
     std::vector<ModBase *> d_modBaseVect;   // defined modalities
@@ -35,7 +35,7 @@ class Modalities
             //      a size_t variables in each used modality
         void resetCounters(size_t nRounds);  
 
-                                    // returns ~0U if 'modality' is unknown
+                                // returns UNDEFINED if 'modality' is unknown
         uint16_t find(std::string const &modality) const;
 
 // double specificity(age) const: age may not be negative
