@@ -17,8 +17,6 @@ class MRI: public ModBase
     VSD d_sensitivity;
     VSD d_specificity;
 
-    StringVect d_base;
-
     public:
         MRI();
         ~MRI() override;
@@ -27,8 +25,6 @@ class MRI: public ModBase
         void setSensitivity();
         void setSpecificity();
 
-        VSDvect const *vDose() const override;               // 1
-        double vDose(uint16_t idx) const override;          // 2
         void vInsert(std::ostream &out) const override;
         double vSensitivity(size_t idx) const override;
         double vSpecificity(double age) const override;
