@@ -21,6 +21,10 @@ bool Options::alter(int optChar, std::string const &value)
             d_base[ANALYSIS] = value;
         break;
 
+        case 'c':
+            d_cancer[ANALYSIS] = value;
+        break;
+
         case 'C':
             d_config[ANALYSIS] = value;
         break;
@@ -54,11 +58,6 @@ bool Options::alter(int optChar, std::string const &value)
             d_spreadFile[ANALYSIS] = value;
         break;
 
-
-//        case 'T':
-//            setFile(d_cumTotalriskFile = value, 'T');
-//        break;
-
         case 't':
             tumorAge(value);
         break;            
