@@ -1,7 +1,7 @@
-//#define XERR
+#define XERR
 #include "options.ih"
 
-    // dest[0]: as specified, dest[1]: as used
+    // dest[0] (STARTUP): as specified, dest[1] (ANALYSIS): as used
 void Options::fileOption(string *dest, int option)
 {
     if (not d_arg.option(&dest[STARTUP], option))
@@ -12,5 +12,10 @@ void Options::fileOption(string *dest, int option)
 
         if (dest[STARTUP] == "!")             // specified as `!': do not use
             dest[STARTUP].clear();
+        else if (option == 'P')
+        {
+            if (dest[STARTUP].find('/') == string::npos)
+                dest[STARTUP].insert(0, 1, '+');
+        }
     }
 }
