@@ -1,9 +1,12 @@
-//#define XERR
+#define XERR
 #include "options.ih"
 
 Options::Options()
 :
-    d_arg(Arg::instance())
+    d_arg(Arg::instance()),
+    d_naturalDeathAge(END_AGE),
+    d_tumorAge(END_AGE),
+    d_lastCase(0)
 {
     imsg.off();
 
@@ -25,16 +28,20 @@ Options::Options()
     fileOption(d_spreadFile, 's');
     fileOption(d_parametersFile, 'P');
 
-
     string value;
     if (d_arg.option(&value, 'a'))
         deathAgeOption(value);
 
+    if (d_arg.option(&value, 'd'))
+        cumDeathOption(value);
+
     if (d_arg.option(&value, 't'))
         tumorAgeOption(value);
 
     if (d_arg.option(&value, 'l'))
         lastCaseOption(value);
+
+    setSimulationType();
 }
 
 
