@@ -3,7 +3,7 @@
 
 void Options::tumorAgeOption(string const &value)
 {
-    d_specified[0] += 't';
+    d_specified[STARTUP] += 't';
     tumorAge(value);
 }
 
