@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "parser.ih"
 
 //static 
@@ -6,6 +6,8 @@ Parser::Lines Parser::any(StringVect const &keywords)
 {
     Lines lines = Parser::lines(keywords);
 
+//xerr("lines " << keywords.back() << ": " << lines.size());
+
     if (not lines)
         Err::msg(Err::MISSING_SPEC) << sectionList(keywords) << endl;
 
