@@ -28,6 +28,7 @@ Parser::MapValue scenario
             {"generator:",  new Parser },
             {"seed:",       new Parser },
             {"cases:",      new Parser },
+            {"death:",      new Parser },
         }
     }
 };
@@ -55,100 +56,22 @@ Parser::MapValue breastDensities
     }
 };
 
-Parser::MapValue mamDose
-{
-    "Dose:",
-    new Parser
-    {
-        {
-            {"bi-rad:",   new Parser },
-        }
-    }
-};
-
-Parser::MapValue mamM
-{
-    "M:",
-    new Parser
-    {
-        {
-            {"bi-rad:",   new Parser },
-        }
-    }
-};
-
-Parser::MapValue mamBeta
-{
-    "Beta:",
-    new Parser
-    {
-        {
-            {"nr:",   new Parser },
-        }
-    }
-};
-
-Parser::MapValue mamSpecificity
-{
-    "Specificity:",
-    new Parser
-    {
-        {
-            {"ageGroup:",   new Parser },
-        }
-    }
-};
-
 Parser::MapValue mammo
 {
     "Mammo:",
     new Parser
     {
         {
-            {"costs:",            new Parser },
-            {"systematicError:",  new Parser },
-            mamDose, 
-            mamM,
-            mamBeta,
-            mamSpecificity,
+            {"beta:",               new Parser },
+            {"costs:",              new Parser },
+            {"dose:",               new Parser },
+            {"m:",                  new Parser },
+            {"specificity:",        new Parser },
+            {"systematicError:",    new Parser },
         }
     }
 };
 
-Parser::MapValue tomDose
-{
-    "Dose:",
-    new Parser
-    {
-        {
-            {"bi-rad:",   new Parser },
-        }
-    }
-};
-
-Parser::MapValue tomSensitivity
-{
-    "Sensitivity:",
-    new Parser
-    {
-        {
-            {"bi-rad:",   new Parser },
-        }
-    }
-};
-
-Parser::MapValue tomSpecificity
-{
-    "Specificity:",
-    new Parser
-    {
-        {
-            {"ageGroup:",   new Parser },
-        }
-    }
-};
-
-
 Parser::MapValue tomo
 {
     "Tomo:",
@@ -156,9 +79,9 @@ Parser::MapValue tomo
     {
         {
             {"costs:",          new Parser },
-            tomDose,
-            tomSpecificity,
-            tomSensitivity,
+            {"dose:",           new Parser },
+            {"sensitivity:",    new Parser },
+            {"specificity:",    new Parser },
         }
     }
 };
@@ -176,6 +99,20 @@ Parser::MapValue mri
     }
 };
 
+Parser::MapValue ct
+{
+    "CT:",
+    new Parser
+    {
+        {
+            {"costs:",          new Parser },
+            {"dose:",           new Parser },
+            {"sensitivity:",    new Parser },
+            {"specificity:",    new Parser },
+        }
+    }
+};
+
 Parser::MapValue modalities
 {
     "Modalities:", 
@@ -184,15 +121,41 @@ Parser::MapValue modalities
         { // map
             mammo,
             tomo,
-            mri
+            mri,
+            ct
         }
     }
 };
 
-
-Parser::MapValue incNormal
+Parser::MapValue incMale
 {
-    "Normal:",
+    Globals::label(MALE),
+    new Parser
+    {
+        {
+            {"lifetimeRisk:", new Parser },
+            {"meanAge:",      new Parser },
+            {"stdDev:",       new Parser },
+        }
+    }
+};
+
+Parser::MapValue incFemale
+{
+    Globals::label(FEMALE),
+    new Parser
+    {
+        {
+            {"lifetimeRisk:", new Parser },
+            {"meanAge:",      new Parser },
+            {"stdDev:",       new Parser },
+        }
+    }
+};
+
+Parser::MapValue incBreast
+{
+    Globals::label(BREAST),
     new Parser
     {
         {
@@ -238,7 +201,9 @@ Parser::MapValue tumIncidence
     new Parser
     {
         {
-            incNormal,
+            incMale,
+            incFemale,
+            incBreast,
             incBrca1,
             incBrca2,
         }
@@ -252,6 +217,7 @@ Parser::MapValue groDoublingTime
     {
         {
             {"ageGroup:", new Parser},
+            {"lung:",     new Parser},
         }
     }
 };
@@ -262,8 +228,9 @@ Parser::MapValue tumGrowth
     new Parser
     {
         {
-            {"start:", new Parser },
-            {"selfDetect:", new Parser },
+            {"start:",  new Parser },
+            {"breast:", new Parser },
+            {"lung:",   new Parser },
             groDoublingTime,
         }
     }
@@ -275,7 +242,35 @@ Parser::MapValue tumSurvival
     new Parser
     {
         {
-            {"type:", new Parser },
+            {"type:",   new Parser },
+            {"lung0:",  new Parser },
+            {"lung1:",  new Parser },
+            {"lung2:",  new Parser },
+            {"lung3:",  new Parser },
+        }
+    }
+};
+
+Parser::MapValue s3
+{
+    "S3:",
+    new Parser
+    {
+        {
+            {"prob:", new Parser },
+        }
+    }
+};
+
+Parser::MapValue tumBeir7
+{
+    "Beir7:",
+    new Parser
+    {
+        { // map
+            { "breast:",    new Parser },
+            { "male:",      new Parser },
+            { "female:",    new Parser },
         }
     }
 };
@@ -288,15 +283,17 @@ Parser::MapValue tumor
         { // map
             tumIncidence,
             tumGrowth,
+            tumBeir7,
             { "beir7:",     new Parser },
             tumSurvival,
+            s3,
         }
     }
 };
 
 Parser::MapValue cosDiscount
 {
-    "Discount:", 
+    "Discount:",
     new Parser
     {
         { // map
@@ -321,13 +318,13 @@ Parser::MapValue costs
 
 } // namespace
 
-Parser::Map Parser::s_map
-{
-    scenario,
-    costs,
-    screening,
+Parser::Map Parser::s_map       // see the configuration file: these are the 
+{                               // configurations for the top-level keywords
+    scenario,                   // e.g., scenario here (above) and Scenario:
+    costs,                      // in the configuration file
     breastDensities,
     modalities,
+    screening,
     tumor,
 };
 
