@@ -1,13 +1,15 @@
-//#define XERR
+#define XERR
 #include "parser.ih"
 
 // static
-std::vector<LineInfoVect> const &Parser::keywordsLines(
-                                            StringVect const &keywords)
+LineInfoVect const &Parser::keywordsLines(StringVect const &keywords)
 {
     Map const *mapPtr = &s_map;
     Map::const_iterator mapIter;
 
+            // E.g., Scenario: iterator: returns the pointer to the Parser
+            //  at Scenario's iterator: specification
+
     for (auto const &keyword: keywords)         // visit the range of keywords
     {
         mapIter = mapPtr->find(keyword);        // ptr to Map::value_type
@@ -19,6 +21,14 @@ std::vector<LineInfoVect> const &Parser::keywordsLines(
         mapPtr = &mapIter->second->d_map;       // use the next keyword
     }
 
-                                                // return the first used 
-    return mapIter->second->d_lines;            // LineInfoVect
+    // with Scenario: death: this is just one line, which may be empty,
+    //  in which case it's followed by 101 cumulative death probabilities
+    //  or it may contain one word, which is the name of the file containing
+    //  the specifications
+    return mapIter->second->d_lines;            // return the LineInfoVect
 }
+
+
+
+
+
