@@ -1,21 +1,24 @@
-//#define XERR
+#define XERR
 #include "parser.ih"
 
+//extern size_t addCount;
+
+    // load an analysis file specification
 void Parser::load(std::istream &in, uint16_t startLineNr,   
                   StringVect &labels, 
                   OptionsVect &options)
 {
     ConfigLines lines{ in, startLineNr };   // read the current stream
 
-    setLabels(lines, labels);
-    setOptions(lines, options);
+    setLabels(lines, labels);               // set label: specifications
 
-    addLineInfoVectors(s_map);              // add (empty) LineInfoVects at
-                                            // the map's deepest nesting 
-                                            // levels
+    setOptions(lines, options);
 
     vector<Map *> mapPtrVect{ &s_map };     // start loading at the top
 
-    while (lines.get())                     // add the config lines
+                                            // add the config lines
+    while (lines.get())                     // to the matching Parser
         addConfigLine(mapPtrVect, lines, ANALYSIS);
 }
+
+
