@@ -27,15 +27,13 @@ struct Parser
         uint16_t    lineNr;
     };
 
-    typedef std::vector<OptionInfo>     OptionsVect;
+    using OptionsVect = std::vector<OptionInfo>;
 
     private:
-        typedef std::unordered_map<std::string, Parser * > Map;
+        using Map = std::unordered_map<std::string, Parser * >;
     
-                                            // vectors of LineInfoVects
                                             // each element holds the specs
-        std::vector<LineInfoVect> d_lines;  // of one series of keywords
-
+        LineInfoVect d_lines;               // of one series of keywords
         Map d_map;
     
         static Map s_map;
@@ -51,132 +49,144 @@ struct Parser
             LineInfoVect::const_iterator d_end;     // of a selected vector
             
             public:
-                LineInfo const *get();          // by repeated calls get all 
-                                                // lines, from the first to 
-                                                // the last until 0 is 
-                                                // returned
+                                         // by repeated calls get all lines, 
+                                         // from the first to the last until 
+                                         // 0 is returned
+                LineInfo const *get();                          // linesget.cc
+
                 unsigned size() const;
-                operator bool() const;
+                operator bool() const;          // size() != 0
 
             private:
-                Lines(LineInfoVect const &lines);   // no lines found  1.f (ih)
+                                                    // no lines found     
+                Lines(LineInfoVect const &lines);   // lineslines1.cc
 
-                                                    // >= 1 line found 2.f (ih)
-                Lines(LineInfoVect::const_iterator const &begin,
+                                                    // >= 1 line found
+                                                    // lineslines2.cc
+                Lines(LineInfoVect::const_iterator const &begin,    
                       LineInfoVect::const_iterator const &end);
 
                 Lines(Lines const &other) = default;
 
-                LineInfoVect::const_iterator begin() const;         // .f (ih)
-                LineInfoVect::const_iterator end() const;           // .f (ih)
+                LineInfoVect::const_iterator begin() const;             // .ih
+                LineInfoVect::const_iterator end() const;               // .ih
         };
             
-        typedef Map::value_type MapValue;
-        
-        Parser() = default;
-        Parser(Map &&tmp);
+        using MapValue = Map::value_type;
 
-                                                    // analysis file        1.
-        void load(std::istream &in, uint16_t startLineNr,   
-                  StringVect &labels, 
-                  OptionsVect &options);
+        Parser();                                                       // 1.
+        Parser(Map &&tmp);                                              // 2.
 
-        void load(std::string const &fname);        // continuration file   2.
-
-        static VSDvect VSDparameters(
-                            VaryType varyType, StringVect const &keywords,
-                            std::initializer_list<char> const &required);
-                            
+        ~Parser();
 
             // any number (>= 1) lines is OK
         static Lines any(StringVect const &keywords);
 
-            // exactly 1 configuration line is required
-        static Lines one(StringVect const &keywords);
-
-            // extract exactly one value associated with keywords
-        template <Extractable Type>                                 // .f
-        static bool one(StringVect const &keywords, Type &dest);
-
-
-            // exactly 1 line is required.                          // 1.f
-        static bool nonNegative(StringVect const &keywords, double &dest);
-        static bool positive(StringVect const &keywords, double &dest); // .f
-
-        template <std::integral Type>                               // 2.f
-        static bool nonNegative(StringVect const &keywords, Type &dest);
-
-            // exactly 1 line is required
-        static bool proportion(StringVect const &keywords, double &dest);
-
                     // extract 'dest' variables from lines.get()->tail
                     // returns 'good' if ok, else if no lines then
                     // eof() else fail() + error msg
-        template <Extractable ...Types>                                 // 1.f
+        template <Extractable ...Types>                                 // .f
         static std::istringstream extract(Lines &&ines, 
                                           Types &...dest);
 
                     // same as 1.f, but LineInfo is already available
                     // extracts from line.tail
-        template <Extractable ...Types>                                 // 2.f
+        template <Extractable ...Types>                                 // .f
         static std::istringstream extract(LineInfo const &line, 
                                           Types &...dest);
 
                     // extract 'size' 'dest' elements from lines.get()->tail
                     // return values as with extract1.f
-        template <Extractable Type>                                     // 3.f
+        template <Extractable Type>                                     // .f
         static std::istringstream extract(Lines &&lines, Type *dest, 
                                                         size_t size);
 
+            // extract 'dest' values from one configuration line at 'keywords'
+        template <Extractable ...Types>                                 // .f
+        static std::istringstream extract(StringVect const &keywords,
+                                          Types &...dest);
+
+        static bool hasSection(StringVect const &keywords);
+
+                                                    // analysis file
+        void load(std::istream &in, uint16_t startLineNr,               // 1.
+                  StringVect &labels, 
+                  OptionsVect &options);
+
+        void load(std::string const &fname);        // configuration file  2. 
+
+            // requires specs like Survival:
+            //  type:  a        .00004475   .000004392  Normal  
+            //  type:  b       1.85867      .0420       Normal
+        static VSDvect VSDparameters(                               //  1.cc
+                            VaryType varyType, StringVect const &keywords,
+                            std::initializer_list<char> const &required);
+                            
+            // exactly 1 configuration line is required
+        static Lines one(StringVect const &keywords);
+
+            // requires one line specs like Mammo:
+            //  m:     .136    .136    .136    .136
+
+        static VSDvect VSDparameters(                               //  2.cc
+                            VaryType varyType, StringVect const &keywords,
+                            size_t nRequired);
+                            
+        // exactly 1 line is required.                              // .f
+        static bool nonNegative(StringVect const &keywords, double &dest);
+
+        template <std::integral Type>                                   // .f
+        static bool nonNegative(StringVect const &keywords, Type &dest);
+
+            // extract exactly one value associated with keywords
+        template <Extractable Type>                                     // .f
+        static bool one(StringVect const &keywords, Type &dest);
+
+        static bool positive(StringVect const &keywords, double &dest); // .f
+
+            // exactly 1 line is required
+        static bool proportion(StringVect const &keywords, double &dest);
+
     private:
-        static Lines lines(StringVect const &keywords);
-
-        static std::string sectionList(StringVect const &keywords);
-
-        static bool atLeast(double minimum, 
-                            StringVect const &keywords, double &dest);
-
-
-        template <Extractable Type, Extractable ...Types>               // 4.f
-        static bool extract(std::istream &in, Type &first, Types &...more);
-        static bool extract(std::istream &in);                  // used in 4.f
-
-        static std::vector<LineInfoVect> const &keywordsLines(
-                                            StringVect const &keywords);
-
-        static void setLabels(ConfigLines &parser, StringVect &labels);
-        static void setOptions(ConfigLines &parser, OptionsVect &options);
-
-                                        // deepest nesting level in the map
-        static bool endPoint(Map::value_type const &mapValue);
-
                                         // add the next parser line to the
                                         // appropriate map-section
         static void addConfigLine(std::vector<Map *> &mapPtrVect, 
                                   ConfigLines &lines, ParamsSrc src);
 
+        static bool atLeast(double minimum, 
+                            StringVect const &keywords, double &dest);
+
+        static std::string checkDeath(ConfigLines &configLine);
+
+                                        // deepest nesting level in the map
+        static bool endPoint(Map::value_type const &mapValue);
+
+
+        template <Extractable Type, Extractable ...Types>               // .f
+        static bool extract(std::istream &in, Type &first, Types &...more);
+
+        static bool extract(std::istream &in);                          // .f
+
+                                                    // define d_lines[0]    
+                                                    // at s_map's deepest   
+        static void initLineInfoVects(Map &map);    // nesting levels       
+
+        static LineInfoVect const &keywordsLines(StringVect const &keywords);
+
+        static Lines lines(StringVect const &keywords);                 //  1.
+
         static void locateError(std::vector<Map *> &mapPtrVect, 
                                 ConfigLines &lines, ParamsSrc src);
 
-                                                // add (empty) LineInfoVects 
-                                                // at s_map's deepest nesting 
-        static void addLineInfoVectors(Map &map); //                  levels
+        static std::string sectionList(StringVect const &keywords);
 
+        static void setLabels(ConfigLines &parser, StringVect &labels);
+        static void setOptions(ConfigLines &parser, OptionsVect &options);
+
+        static void rmLineInfoVectors(Map &map); 
 };
 
-#include "extract1.f"
-#include "extract2.f"
-#include "extract3.f"
-#include "extract4.f"
-
-#include "one.f"
-#include "nonnegative1.f"
-#include "nonnegative2.f"
-
-#include "positive.f"
-
-#include "linessize.f"
-#include "linesopbool.f"
+#include "parser.f"
 
 #endif
 
