@@ -1,18 +1,22 @@
-//#define XERR
+#define XERR
 #include "parser.ih"
 
+// OptionsVect: vector of OptionInfo elements, processed by actualize()
+// OptionInfo: defined by Parser
+
 // static
-void Parser::setOptions(ConfigLines &parser, OptionsVect &options)
+void Parser::setOptions(ConfigLines &parser, OptionsVect &optionsVect)
 {
     while 
     (
         parser.get()                                // got a line and it's not
         and                                         // a top-level parser
         s_map.find(parser.key()) == s_map.end()     // parameter
-    )
-        options.push_back( 
-                    { 
-                        parser.key().back() == ':' ?
+    )                                               
+                                                // store the option spec.
+        optionsVect.push_back(                  // long option name and value
+                    {                               
+                        parser.key().back() == ':' ?    // rm a final :
                             parser.key().substr(0, parser.key().length() - 1)
                         :
                             parser.key(),
