@@ -1,11 +1,11 @@
-//#define XERR
+#define XERR
 #include "random.ih"
 
-void Random::reinit(size_t nCases, bool vary, GeneratorType type)
-{
-    d_vary = vary;
+// Called from Loop::iterate, defines the betadistributions if vary is set
 
-    if (d_vary and nCases == 1)
+void Random::reinit(size_t nCases, GeneratorType type)
+{
+    if (Globals::vary() and nCases == 1)
         throw Exception{} << "'spread: true' cannot be used with 'cases: 1'";
 
     d_nCases = nCases;
