@@ -3,6 +3,5 @@
 
 double Random::uniform()
 {
-//    cerr.put('.');
-    return d_uniform(d_engine);
+    return d_uniform(d_engine[UNIFORM]);
 }
