@@ -1,6 +1,7 @@
 #ifndef INCLUDED_SCENARIO_
 #define INCLUDED_SCENARIO_
 
+#include <iosfwd>
 
 // Scenario:
 //   # default values are shown
@@ -26,11 +27,9 @@ class Scenario
 {
     StringVect d_base;
 
-    bool d_vary;              // true: apply variations to configuration
-                                //       parameters
-
     GeneratorType d_generatorType;
 
+    std::vector<double> d_cumDeathProportions;
     size_t d_nIterations;
     size_t d_nCases;
     size_t d_seed;
@@ -41,7 +40,8 @@ class Scenario
     public:
         Scenario();
 
-        bool vary() const;        // true: vary to config. params
+        std::vector<double> const &cumDeathProp() const;
+
         size_t nIterations() const;
         size_t seed() const;
         GeneratorType generatorType() const;
@@ -50,41 +50,22 @@ class Scenario
         void writeParameters(std::ostream &out, size_t iter) const;
 
     private:
+        bool appendCumDeath(std::string const &line);
+        void checkCumDeath(std::string const &source) const;
+        void readCumDeath(std::string const &fname);
+
+        void setDeath();                    // set the cum. death proportions
         void setNiterations();              // set n iteratations
         void setNcases();                   // set nCases
         void setSeed();                     // set seed value
         void setGeneratorType();            // set the random generator type
-        void setVary();                   // set variableSpred 
+        void setVary();                     // set variableSpread 
 
-        static int find(StringVect const &haystack, 
-                        std::string const &needle);
+        static int find(StringVect const &haystack,     // must succeed or 
+                        std::string const &needle);     // Err::specification
 };
 
-
-inline bool Scenario::vary() const
-{
-    return d_vary;
-}
-
-inline size_t Scenario::nIterations() const
-{
-    return d_nIterations;
-}
-
-inline size_t Scenario::seed() const
-{
-    return d_seed;
-}
-
-inline GeneratorType Scenario::generatorType() const
-{
-    return d_generatorType;
-}
-
-inline size_t Scenario::nCases() const
-{
-    return d_nCases;
-}
+#include "scenario.f"
 
 #endif
 
