@@ -1,10 +1,9 @@
-//#define XERR
+#define XERR
 #include "scenario.ih"
 
 void Scenario::setNcases()
 {
     d_base.back() = "cases:";
-
     Parser::nonNegative(d_base, d_nCases);
 }
 
