@@ -10,6 +10,6 @@ void Scenario::writeParameters(ostream &out, size_t iter) const
         "  n iterations: " << d_nIterations << "\n"
         "  n cases:      " << d_nCases << "\n"
         "  seed          " << d_seed << "\n"
-        "  spread:       " << s_bool[d_vary] << "\n"
+        "  spread:       " << s_bool[Globals::vary()] << "\n"
         "\n";
 }
