@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "screening.ih"
 
     // false: round: none was specified
@@ -8,6 +8,8 @@ bool Screening::addRound(LineInfo *noneLine, LineInfo const &lineInfo)
 {
     Round round(d_modalities.modalityIDs());
 
+//xerr(lineInfo.txt);
+
     auto in = Parser::extract(lineInfo, round);   // extracts the age
 
     if (round.none())
@@ -19,31 +21,18 @@ bool Screening::addRound(LineInfo *noneLine, LineInfo const &lineInfo)
     if (not in)
         return true;
 
-    if (not increasingAge(round))
+    if (not increasingAge(round))           // ages must increase
     {
         Err::msg(Err::ROUND_AGES_DONT_INC) << endl;
         return true;
     }
 
-    string modality;
-    while (in >> modality)
-    {
-        Err::Context context;
+    if (addModality(in, round))
+        d_roundVect.push_back(move(round));
 
-        if (uint16_t idx = d_modalities.find(modality); idx == ~0U)
-            context = Err::UNDEFINED_MODALITY;
-        else
-        {
-            if (round.add(idx))
-                continue;
-
-            context = Err::MODALITY_REPEATED;
-        }
-
-        Err::msg(context) << endl;
-        return true;
-    }
-
-    d_roundVect.push_back(move(round));
     return true;
 }
+
+
+
+
