@@ -1,9 +1,13 @@
 //#define XERR
 #include "screening.ih"
 
+// called from errRisk1405.cc
+// index is the biRad column index to use with BC
+// and 0 when used with LC, as LC has no dose variation.
+
 // static
 double Screening::beir7Err(uint16_t age, 
-                           Round const &round, uint16_t biradIdx, double beta, 
+                           Round const &round, uint16_t index, double beta, 
                            double eta, Modalities const &modalities)
 {
     double risk = 1;
@@ -11,7 +15,7 @@ double Screening::beir7Err(uint16_t age,
     double factor = beta * pow(age / 60.0, eta) / 1000;
 
     for (ModBase const *modBase: modalities.use(round.modalityIndices()))
-        risk *= (1 + factor * modBase->dose(biradIdx));
+        risk *= (1 + factor * modBase->dose(index));
 
     return risk;
 }
