@@ -40,16 +40,20 @@ class Screening
 
     RoundVect d_roundVect;
 
-    double d_rate;
+                                            // attendance rate, configured at
+    double d_rate;                          // Screening: attendanceRate:
 
     // points to static members:                        // errRisk1404 or 
     void (*d_errRiskVector)(DoubleVect &,               // errRiskA1405
                             Modalities const &,
                             Round const &, uint16_t, double, double);
+
+    bool d_lungCancer;
+
     public:
         Screening(Modalities const &modalities);
 
-        double rate() const;
+        double rate() const;                                            // .f
 
         DoubleVect radiationRisk(
                             Modalities const &modalities,
@@ -58,17 +62,16 @@ class Screening
 
         DoubleVect ages() const;  // vector of ages of the screening rounds
 
-        uint16_t nRounds() const;
-        double age(size_t idx) const;   
+        uint16_t nRounds() const;                                       // .f
+        double roundAge(size_t idx) const;          // age at round idx    .f
+
                                                     // roundIdx is, e.g. 
-        Round const &round(size_t roundIdx) const;  // Loop::d_round
+        Round const &round(size_t roundIdx) const;  // Loop::d_round       .f
 
         void writeParameters(std::ostream &out) const;
 
     private:
-        void setAttendanceRate();
-
-        void setRounds();
+        bool addModality(std::istream &in, Round &round);
                                             // false: round: none, noneLine
                                             // has the last noneLine
         bool addRound(LineInfo *noneLine, LineInfo const &line);
@@ -81,6 +84,7 @@ class Screening
                         double beta, double eta);
 
         static void errRisk1405(DoubleVect &riskVect, 
+
                         Modalities const &modalities,
                         Round const &round, uint16_t biRadIdx, 
                         double beta, double eta);
@@ -94,28 +98,21 @@ class Screening
                                uint16_t idx, double beta, double eta, 
                                Modalities const &modalities);
 
+        void setAttendanceRate();
+
+        void setRounds();
+
+//        bool warnCT(std::string const &modality);
+//        bool warnedCT(std::string const &modality);
+//        bool warnNotCT(std::string const &modality);
+//        bool warnedNotCT(std::string const &modality);
 };
 
-inline double Screening::rate() const
-{
-    return d_rate;
-}
-
-inline uint16_t Screening::nRounds() const
-{
-    return d_roundVect.size();
-}
-
-inline double Screening::age(size_t idx) const
-{
-    return d_roundVect[idx].age();
-}
-
-inline Round const &Screening::round(size_t idx) const
-{
-    return d_roundVect[idx];
-}
+#include "screening.f"
 
+//                                                // CT for lung cancer,
+//                                                // not CT for breast cancer
+//    bool (Screening::*d_checkCT)(std::string const &modality);
 
 //
 //        void beir7dose(double const *dose);                         //  .h
