@@ -1,13 +1,13 @@
-//#define XERR
+#define XERR
 #include "screening.ih"
 
 void Screening::setRounds()
 {
     d_base.back() = "round:";
 
-    auto lines = Parser::any(d_base);
+    auto lines = Parser::any(d_base);           // obtain the 'round:' lines
 
-    bool useRounds = true;
+    bool allOK = true;
     LineInfo noneLine;
 
     while (true)
@@ -15,11 +15,14 @@ void Screening::setRounds()
         LineInfo const *line = lines.get(); 
         if (line == 0)
             break;
-        
-        useRounds = addRound(&noneLine, *line) and useRounds;
+
+//xerr(line->txt);
+
+                                                // add a round specification
+        allOK = addRound(&noneLine, *line) and allOK;
     }
 
-    if (d_roundVect.size() and not useRounds)
+    if (d_roundVect.size() and not allOK)       // not all rounds were OK
     {
         Err::reset(noneLine);
         Err::msg(Err::ROUND_NONE) << noneLine.txt << endl;
