@@ -8,11 +8,13 @@ void Simulator::run()
     {
         uint16_t lineNr = d_lineNr;        
                                             // read the next analysis specs
-        string spec = (this->*d_nextSpecs)();   
+        string spec = (this->*d_nextSpecs)();   // cmdLineAnalysis() or
+                                                // fileAnalysis()
 
         emsg.setCount(0);
 
         Analysis analysis{ istringstream{ spec }, lineNr };
+
         analysis.run();                     // run the simulation
     }
 }
