@@ -11,7 +11,8 @@ void Simulator::setAnalysisSource()
         d_nextSpecs = &Simulator::cmdLineAnalysis;  //       cmd line args
     }
     else
-    {                                               // otherwise from file
+    {                                   // otherwise find the (next) Analysis: 
+                                        // line in the analysis file
         d_ifstream = Exception::factory<ifstream>(arg[0]);
         string line;
         while (getline(d_ifstream, line))
