@@ -26,7 +26,9 @@ class Simulator
     private:
         bool nextAnalysis();
 
-        void setAnalysisSource();
+        void setAnalysisSource();       // extra specifications either on the
+                                        // cmd line or the next 'analysis:'
+                                        // specification from file
 
         std::string cmdLineAnalysis();
         std::string fileAnalysis();
