@@ -12,8 +12,8 @@
     
 double Tomo::vSpecificity(double age) const
 {
-    return find_if(d_specificity.rbegin(), d_specificity.rend(), 
-                    [&](Specificity const &spec)
+    return find_if(d_specVect.rbegin(), d_specVect.rend(), 
+                    [&](AgeGroupVSD const &spec)
                     {
                         return spec.beginAge() < age;
                     }
