@@ -5,7 +5,7 @@
 void Tumor::characteristics(double age)
 {
     check("size");
-  
+
     if ((d_present = (d_detectableAge <= age)))            // there is a tumor
     {
         d_diameter = 
@@ -19,6 +19,11 @@ void Tumor::characteristics(double age)
         d_volume = 0;
         d_diameter = 0;
     }
+
+    d_survival.setVSD(d_diameter);
+    
+xerr("age: " << age << ", detectable age: " << d_detectableAge << ", diameter = " << d_diameter);
+
 }
 
 
