@@ -3,7 +3,7 @@
 
 void Tumor::check(char const *type) const
 {
-    if (d_age == NO_TUMOR)
+    if (d_selfDetectAge == NO_TUMOR)
         throw Exception{} << "cannot determine tumor " << type << 
                              " for a non-existing tumor";
 }
