@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "tumor.ih"
 
 //    if (0.120662 < rndTumor and rndTumor < 0.120664)
@@ -14,16 +14,20 @@ bool Tumor::tumorAge()
 {
     Random &random = Random::instance();
 
-    d_age = findAge(d_tumorInfo.cumTotalRisk(), random.uniformCase());
+// double rnd;
+    d_selfDetectAge = findAge(d_tumorInfo.cumTotalRisk(), 
+// rnd = 
+        random.uniformCase());
 
-    xerr("random tumor prob: " << rndTumor << ", age " << d_age);
 
-    Options::instance().fixedTumorAge(d_age);
+//xerr("random tumor prob: " << rnd << ", age " << d_selfDetectAge);
 
-    if (d_age <= MAX_AGE)
+    Options::instance().fixedTumorAge(d_selfDetectAge);
+
+    if (d_selfDetectAge <= MAX_AGE)
         return true;
 
-    d_age = NO_TUMOR;
+    d_selfDetectAge = NO_TUMOR;
 
     random.uniformCase();             // extra calls to synchronize the
     random.logNormal(0, 0);           // random generator between 
