@@ -1,4 +1,4 @@
-#define XERR
+//#define XERR
 #include "tumorinfo.ih"
 
     // see void calcTotalRisk(int carrierIndex)
@@ -8,12 +8,14 @@ void TumorInfo::cumTotalRisk(DoubleVect const &radiationRisk)
     double sum = 0;
     d_cumRisk.clear();
 
-    uint16_t carrierIdx = d_incidence.carrier();
+xerr("0");
+    uint16_t idx = d_incidence.index();
 
     auto iter = radiationRisk.begin();
 
-    for (double risk: d_incidence.tumorRisk(carrierIdx))
+    for (double risk: d_incidence.tumorRisk(idx))
         d_cumRisk.push_back(sum += risk * *iter++);
+xerr("0");
 }
 
 
