@@ -15,14 +15,13 @@ class Scenario;
 class TumorInfo: public Globals
 {
     Incidence d_incidence;
-    Beir7     d_beir7;
+    Beir7     d_beir7;                  // initialized by Beir7's constructor
     Growth    d_growth;
     Survival  d_survival;
 
     DoubleVect d_cumRisk;
 
     public:
-                                 
         void vary(std::ostream &out);           // vary parameters 
                                     
         Incidence const &incidence() const;
@@ -30,7 +29,7 @@ class TumorInfo: public Globals
         uint16_t  induction() const;            // beir model to use
         Beir7     const &beir7() const;
         Growth    const &growth() const;
-        Survival  const &survival() const;
+        Survival  &survival();
 
         void cumTotalRisk(DoubleVect const &radiationRisk);
 
@@ -57,7 +56,7 @@ inline Growth const &TumorInfo::growth() const
     return d_growth;
 }
 
-inline Survival const &TumorInfo::survival() const
+inline Survival &TumorInfo::survival()
 {
     return d_survival;
 }
