@@ -1,8 +1,8 @@
-//#define XERR
+#define XERR
 #include "vsd.ih"
 
 std::ostream &VSD::insert(std::ostream &out) const
 {
-    return Globals::setWidthPrec(out, s_width, s_prec) << d_value <<
+    return Globals::setWidthPrec(out, s_width, s_prec) << d_orgValue <<
            ",  " << d_dist;
 }
