@@ -14,18 +14,22 @@ class VSD
                                     std::vector<VSD> const &vect);
 
     double d_value = 0;
-    double d_orgValue = 0;                  // initial config. value,
-                                            //  used by vary()
 
-    Distribution d_dist;                    // distribution used for spreading
-                                            // d_value. The distribution
-                                            // receives the 'spread' and the
-                                            // name of the distribution
+    double d_orgValue = 0;      // initial config. value, used by vary(), 
+                                // extracted from the config file
+                                    
 
-    void (*d_valueCheck)(double &value);    // mean, stddev, proportion
+    Distribution d_dist;    // distribution used for spreading d_value. 
+                            // The distribution may receive the 'spread' and 
+                            // receives the name of the distribution. 
+                            // For LC BETA_MALE or BETA_FEMALE is used
+
+                            // meanCheck (VARY_MEAN), posCheck (VARY_NONNEG)
+                            // probCheck (VARY_PROB). No checks for BETA_*,
+    void (*d_valueCheck)(double &value);
+                                                    // addresses of the
+    static void (*s_valueCheck[])(double &value);   // ..Check functions
 
-                                                    // functions checking 
-    static void (*s_valueCheck[])(double &value);   // d_value
     static VaryType s_varyType[];
 
     static unsigned s_indent;
@@ -37,16 +41,25 @@ class VSD
     public:
         VSD(VaryType varyType);
 
-        void vary();                            // was: refresh/spread
+            // vary() modifies d_value by calling d_dist.vary(d_orgValue)
+            // this modifies d_value, after which value() returns the modified
+            // value. The modified value is called using the variation 
+            // computing function set by Distribution::d_vary, e.g. varyMean,
+            // varyNonNeg, etc. The Distribution::vary* functions call the
+            // appropriate random-variation functions, which are active
+            // because of the 'spread: true' configuration.
+        void vary();                        // was: refresh/spread    .f
+                                            // sets d_value as a varied
+                                            // value through d_dist.value()
+
         void showVary(std::ostream &out) const; // the actually used and orig.
                                                 // values
         
-        
-        double value() const;                   // mean or proportion
-        double spread() const;                  // Distribution's value
+        double value() const;                   // mean or percentage       .f
 
-        DistType distType() const;              // was: dist
-        std::string const &distName() const;    // was: name
+                                                // values obtained from d_dist
+        DistType distType() const;              // was: dist                .f
+        std::string const &distName() const;    // was: name                .f
 
         Distribution const &distribution() const;
 
@@ -57,10 +70,15 @@ class VSD
                         unsigned valueIntWidth, unsigned valuePrec,    
                         unsigned distValueWidth, unsigned distPrec);
 
-        static void vary(std::ostream &out,                             // 2
+                                            // write vary info to 'out' 
+        static void vary(std::ostream &out, // hdr should end in ':'    // 2
                         unsigned indent, char const *hdr, 
                         char const *type, char ch, std::vector<VSD> &vect);
-                         
+
+        static void vary(std::ostream &out, // same, no hdr line           3
+                        unsigned indent,
+                        char const *type, char ch, std::vector<VSD> &vect);
+
     private:
         std::ostream &insert(std::ostream &out) const;                  // 1
         
@@ -69,57 +87,16 @@ class VSD
 
         std::istream &extract(std::istream &in);
 
-        static void meanCheck(double &value);
+        static void accept(double &value);
         static void posCheck(double &value);
         static void probCheck(double &value);
 };
 
-typedef std::vector<VSD> VSDvect;
+using VSDvect   = std::vector<VSD>;
+using VSDmatrix = std::vector<std::vector<VSD>>;
 
-inline Distribution const &VSD::distribution() const
-{
-    return d_dist;
-}
+#include "vsd.f"
 
-inline void VSD::vary()
-{
-    d_value = d_dist.vary(d_orgValue);
-}
-
-inline double VSD::value() const
-{
-    return d_value;
-}
-
-inline double VSD::spread() const
-{
-    return d_dist.value();
-}
-    
-inline DistType VSD::distType() const
-{
-    return d_dist.type();
-}
-        
-inline std::string const &VSD::distName() const
-{
-    return Distribution::name(d_dist.type());
-}
-        
-inline std::ostream &operator<<(std::ostream &out, VSD const &vsd)
-{
-    return vsd.insert(out);
-}
-
-inline std::ostream &operator<<(std::ostream &out, VSDvect const &vect)
-{
-    return VSD::insert(out, vect);
-}
-
-inline std::istream &operator>>(std::istream &in, VSD &vsd)
-{
-    return vsd.extract(in);
-}
 
 //                        // charShift != 0 then idx is converted to char 
 //                        // indent: initial indentation
